/*
 * Copyright © 2021-2023 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of ipspiel24-VierConnects-core.
 *
 * ipspiel24-VierConnects-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * ipspiel24-VierConnects-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * ipspiel24-VierConnects-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.ipspiel24.VierConnects.core.domain;

import java.util.List;
import java.util.Optional;

/**
 * Represents a complete row on a {@link VierConnectsBoard board}.
 */
public interface VierConnectsRow {

    /**
     * Returns the type of this row.
     */
    VierConnectsRowType getType();

    /**
     * Returns the index of this row. For horizontal or vertical rows, its range extends from zero to the number of
     * rows/columns minus one. For diagonal rows, only zero (main diagonal) or one (secondary diagonal) are possible.
     */
    int getIndex();

    /**
     * Returns a row state if all fields in this row possess the same field state. Note that this also includes the
     * state {@link VierConnectsFieldState#EMPTY}.
     */
    Optional<VierConnectsFieldState> getState();

    /**
     * Returns the fields of this row.
     */
    List<? extends VierConnectsField> getFields();
}
